.. module:: enaml.widgets.split_item

========================
enaml.widgets.split_item
========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    SplitItem


.. autoclass:: SplitItem
